#!/usr/bin/python
# -*- coding: utf-8 -*-

#Autor: Erickson Silva 
#Email: <erickson.silva@lavid.ufpb.br> <ericksonsilva@live.com>

#LAViD - Laboratório de Aplicações de Vídeo Digital

import os
import csv
import sys
from nltk.tree import Tree
from LerDicionarios import *
from os.path import expanduser
from os import environ, path


class AplicaSinonimos(object):
	'''Aplica sinonimos após aplicação de regras morfológicas/sintáticas.
	'''

	def __init__(self):
		self.dicionarios = LerDicionarios()

	# Itera sobre os tokens obtendo os sinonimos
	def aplicar_sinonimos(self, lista_anotada):
		'''Percorre a lista fazendo a substituição pelos sinonimos.
		'''
		lista_corrigida = []
		palavras_compostas = self.carregar_palavras_compostas()
		for tupla in lista_anotada:
			sinonimo = self.verificar_sinonimo(tupla[0])
			try:
				token_composto_2 = lista_corrigida[-1] + "_" + sinonimo
				token_composto_3 = lista_corrigida[-2] + "_" + lista_corrigida[-1] + "_" + sinonimo
				if token_composto_2.upper() in palavras_compostas:
					lista_corrigida[-1] = token_composto_2
				elif token_composto_3.upper() in palavras_compostas:
					lista_corrigida.pop()
					lista_corrigida[-1] = token_composto_3
				else:
					lista_corrigida.append(sinonimo)
			except IndexError:
				lista_corrigida.append(sinonimo)

		try:
			return " ".join(lista_corrigida)
		except:
			return " ".join([str(x[0]) for x in lista_anotada])

	# Verifica se há sinonimo do token  
	def verificar_sinonimo(self, token):
		'''Verifica se há sinonimo do token.
		'''
		if self.dicionarios.has_sinonimo(token):  
			return self.dicionarios.get_sinonimo(token)
		return token

	def carregar_palavras_compostas(self):
		path = self.localizar_arquivo_palavras_compostas()
		return set(open(path).read().decode('utf-8').split())

	def localizar_arquivo_palavras_compostas(self):
		if platform.system() == 'Windows':
			return environ.get("HOMEDRIVE")+'\\vlibras-libs\\vlibras-translate\data\\palavras_compostas.csv'
		elif "TRANSLATE_DATA" in environ:
			return path.join(environ.get("TRANSLATE_DATA"), "palavras_compostas.csv")
		return expanduser("~")+'/vlibras-translate/data/palavras_compostas.csv'